%define build_devel 1

Summary:	Tools for managing Linux kernel packet filtering capabilities
Name:		iptables
Version:	1.4.0
Release:	%manbo_mkrel 1
License:	GPLv2+
Group:		System/Kernel and hardware
URL:		http://netfilter.org/
Source:		http://www.netfilter.org/files/%{name}-%{version}.tar.bz2
Source1:	iptables.init
Source2:	ip6tables.init
Source3:	iptables.config
Source4:	ip6tables.config
# S100 and up used to be in the added patches
Source100:	libipt_IMQ.c
Source101:	libipt_IFWLOG.c
# (oe) psd comes from iptables-1.3.7, was removed in iptables-1.3.8
Source102:	libipt_psd.c
Source103:	libipt_psd.man
Patch0:		iptables-1.2.8-libiptc.h.patch 
Patch100:	iptables-imq.diff
Patch101:	iptables-IFWLOG_extension.diff
Patch102:	iptables-psd.diff
BuildRequires:	perl-base
BuildRequires:  kernel-source
Provides:	userspace-ipfilter
Requires(post): rpm-helper
Requires(preun): rpm-helper
Conflicts:	ipchains
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
iptables controls the Linux kernel network packet filtering code.
It allows you to set up firewalls and IP masquerading, etc.

Install iptables if you need to set up firewalling for your
network.

%package	ipv6
Summary:	IPv6 support for iptables
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	ipv6
IPv6 support for iptables.

iptables controls the Linux kernel network packet filtering code.
It allows you to set up firewalls and IP masquerading, etc.

IPv6 is the next version of the IP protocol.

Install iptables-ipv6 if you need to set up firewalling for your
network and you're using ipv6.

%if %{build_devel}
%package	devel
Summary:	Development package for iptables
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	kernel-headers

%description devel
The iptables utility controls the network packet filtering code in the
Linux kernel. If you need to set up firewalls and/or IP masquerading,
you should install this package.
%endif

%prep

%setup -q

cp %{SOURCE1} iptables.init
cp %{SOURCE2} ip6tables.init
cp %{SOURCE3} iptables.sample
cp %{SOURCE4} ip6tables.sample

%patch0 -p1 -b .libiptc

# extensions
install -m0644 %{SOURCE100} extensions/
install -m0644 %{SOURCE101} extensions/
# (oe) psd comes from iptables-1.3.7, was removed in iptables-1.3.8
install -m0644 %{SOURCE102} extensions/
install -m0644 %{SOURCE103} extensions/

%patch100 -p0
%patch101 -p0
%patch102 -p0

chmod +x extensions/.*-test

find . -type f | xargs perl -pi -e "s,/usr/local,%{_prefix},g"

%build
%serverbuild
export CFLAGS="${CFLAGS:-%{optflags}} -fPIC"
export OPT="$CFLAGS -DNDEBUG -DNETLINK_NFLOG=5"

# (cg) the old kernel-headers tarball contained the folder
# linux-2.6-pom so we emulate that here...
# Can we tidy this whole thing up and not use a /lib/iptables symplink?
for i in linux-2.6-pom
	do find extensions -name '*.[ao]' -o -name '*.so' | xargs rm -f
	make LD=gcc COPT_FLAGS="$OPT" KBUILD_OUTPUT=/usr/src/linux KERNEL_DIR=/usr/src/linux LIBDIR=/lib all
	rm -fr $i/extensions
	mkdir -p $i/extensions
	mv extensions/*.so $i/extensions
done

# make more devel libs (debian)
ar rcs libiptables.a iptables.o
ar rcs libip6tables.a ip6tables.o

%install
rm -rf %{buildroot}
%serverbuild
export CFLAGS="${CFLAGS:-%{optflags}} -fPIC"
export OPT="$CFLAGS -DNDEBUG -DNETLINK_NFLOG=5"

# Dunno why this happens. -- Geoff
%makeinstall_std \
    COPT_FLAGS="$OPT" \
    LD=gcc \
    BINDIR=/sbin \
    LIBDIR=/lib \
    MANDIR=%{_mandir} \
    KERNEL_DIR=%{_prefix} \
    install install-experimental

%if %{build_devel}
make \
    DESTDIR=%{buildroot} \
    COPT_FLAGS="$OPT" \
    LD=gcc \
    BINDIR=/sbin \
    LIBDIR=%{_libdir} \
    INCDIR=%{_includedir} \
    MANDIR=%{_mandir} \
    KERNEL_DIR=%{_prefix} \
    install-devel 

# static development files
install -d %{buildroot}%{_libdir}
install -m0644 libiptc/libiptc.a %{buildroot}%{_libdir}/libiptc.a
install -m0644 libiptables.a %{buildroot}%{_libdir}/
install -m0644 libip6tables.a %{buildroot}%{_libdir}/

# header development files
install -d %{buildroot}%{_includedir}/{libipq,libiptc,libipulog}
install -m0644 include/ip6tables.h %{buildroot}%{_includedir}/
install -m0644 include/xtables.h %{buildroot}%{_includedir}/
install -m0644 include/iptables.h %{buildroot}%{_includedir}/
install -m0644 include/libipq/*.h %{buildroot}%{_includedir}/libipq/
install -m0644 include/libiptc/*.h %{buildroot}%{_includedir}/libiptc/
install -m0644 include/libipulog/*.h %{buildroot}%{_includedir}/libipulog/
%endif

rm -rf %{buildroot}/lib/iptables
for i in linux-2.6-pom; do
	mkdir -p %{buildroot}/lib/iptables.d/$i
done
for i in linux-2.6-pom/extensions/*.so; do
	for j in %{buildroot}/lib/iptables.d/*; do
		if [ -e %{buildroot}/lib/iptables.d/${i%%%/*}/${i##*/} ]; then
			:
		elif cmp -s $i $j/${i##*/}; then
			ln $j/${i##*/} %{buildroot}/lib/iptables.d/${i%%%/*}/
		else
			cp $i %{buildroot}/lib/iptables.d/${i%%%/*}/
		fi
	done
done

install -d %{buildroot}%{_initrddir}
install -m0755 iptables.init %{buildroot}%{_initrddir}/iptables
install -m0755 ip6tables.init %{buildroot}%{_initrddir}/ip6tables

%clean
rm -rf %{buildroot}

%post
%_post_service iptables
# run only on fresh installation
if [ $1 = 1 ]; then
    /sbin/service iptables check
fi

%triggerpostun -- iptables < 1.2.9-8mdk
# fix upgrade from mdk < 10.2
/sbin/service iptables check

%preun
%_preun_service iptables

%post ipv6
%_post_service ip6tables

%preun ipv6
%_preun_service ip6tables

%files
%defattr(-,root,root,0755)
%doc INSTALL INCOMPATIBILITIES iptables.sample
%{_initrddir}/iptables
/sbin/iptables
/sbin/iptables-save
/sbin/iptables-restore
/sbin/iptables-xml
%{_mandir}/*/iptables*
%dir /lib/iptables.d
%dir /lib/iptables.d/*
/lib/iptables.d/*/libipt*
/lib/iptables.d/*/libxt*

%files ipv6
%defattr(-,root,root,0755)
%doc INSTALL INCOMPATIBILITIES ip6tables.sample
%{_initrddir}/ip6tables
/sbin/ip6tables
/sbin/ip6tables-save
/sbin/ip6tables-restore
%{_mandir}/*/ip6tables*
%dir /lib/iptables.d
%dir /lib/iptables.d/*
/lib/iptables.d/*/libip6t*

%if %{build_devel}
%files devel
%defattr(-,root,root,0755)
%{_includedir}/*.h
%dir %{_includedir}/libipq/
%dir %{_includedir}/libiptc/
%dir %{_includedir}/libipulog/
%{_includedir}/libipq/*.h
%{_includedir}/libiptc/*.h
%{_includedir}/libipulog/*.h
%{_libdir}/libipq.a
%{_libdir}/libiptc.a
%{_libdir}/libiptables.a
%{_libdir}/libip6tables.a
%{_mandir}/man3/*
%endif


%changelog
* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-1mnb1
+ Revision: 181032
- bump release

* Tue Mar 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.9mnb1
+ Revision: 178419
- added fixes to psd and IFWLOG by lcapitulino to hopefully fix #37158

* Sun Feb 24 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.8mnb1
+ Revision: 174357
- pass -fPIC to the CFLAGS

* Mon Feb 18 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.4.0-0.7mnb1
+ Revision: 170652
- replace %%mkrel with %%manbo_mkrel for Manbo Core 1

* Sun Feb 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.0-0.7mdv2008.1
+ Revision: 164942
- fix broken symlink

* Sat Feb 09 2008 Colin Guthrie <cguthrie@mandriva.org> 1.4.0-0.6mdv2008.1
+ Revision: 164496
- Work around the removal of the kernel headers tarball.

* Sat Feb 09 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.0-0.5mdv2008.1
+ Revision: 164392
- remove source 5, a kernel headers which are now a system wide standalone package
- devel package requires kernel-headers
- new license policy

  + Oden Eriksson <oeriksson@mandriva.com>
    - remove the grsecurity stuff, we don't have it anyway

* Thu Jan 24 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.4mdv2008.1
+ Revision: 157396
- enable the build of the IFWLOG extension now that kernel-source-latest is fixed (#37082)

* Tue Jan 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.3mdv2008.1
+ Revision: 156462
- added most of the added extensions as sources instead
- dropped unmaintained extensions

  + Thierry Vignaud <tvignaud@mandriva.com>
    - drop kernel-2.4.x versionning

* Tue Jan 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.2mdv2008.1
+ Revision: 156206
- fix the %%serverbuild stuff again...

* Tue Jan 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.1mdv2008.1
+ Revision: 156091
- 1.4.0
- dropped obsolete patches; P9
- the IFWLOG extension needs rework, it won't build (P6)
- rediffed patches; P1,P7
- rediff P8, but don't apply it just yet
- really use the %%serverbuild rpm macro
- add P10 (psd support)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - remove useless kernel require
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Oct 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.3.8-1mdv2008.1
+ Revision: 98487
- 1.3.8
- rediffed P1,P7,P9
- added more static development and header files

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - new version

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 1.3.7-2mdv2008.0
+ Revision: 36175
- rebuild with correct optflags

  + Per Øyvind Karlsen <pkarlsen@mandriva.com>
    - add missing ipv6 extensions: rt ipv6header hbh frag dst ah
    - reenable IPV4OPTSSTRIP extension
    - enable building of CLUSTERIP module
    - fix install of libiptc.a
    - add iptables-xml
    - new version: 1.3.7
    - regenerate P1
    - cleanups


* Tue Aug 08 2006 Emmanuel Andry <eandry@mandriva.org> 1.3.5-3mdv2007.0
- rebuild for x86_64

* Mon Aug 07 2006 Olivier Blin <blino@mandriva.com> 1.3.5-2mdv2007.0
- use linux-2.6-pom (patch-o-matic) as kernel headers basename (#24147)

* Fri Aug 04 2006 Samir Bellabes <sbellabes@n4.mandriva.com> 1.3.5-1mdv2007.0
- new release
- desactive patch ipp2p
- new kernel-headers

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 1.3.3-6mdk
- convert parallel init to LSB
- mkrel
- Requires(post), Requires(preun)
- remove requires-on-release

* Sat Dec 31 2005 Couriousous <couriousous@mandriva.org> 1.3.3-5mdk
- Add parallel init info

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.3.3-4mdk
- Rebuild

* Wed Aug 10 2005 Samir Bellabes <sbellabes@mandriva.com> 1.3.3-3mdk
- rebuild with new kernel headers 2.6.12-9mdk.

* Wed Aug 03 2005 Samir Bellabes <sbellabes@mandriva.com> 1.3.3-2mdk
- IFWLOG target

* Fri Jul 29 2005 Samir Bellabes <sbellabes@mandriva.com> 1.3.3-1mdk
- update to version 1.3.3

* Wed Jul 27 2005 Samir Bellabes <sbellabes@mandriva.com> 1.3.2-2mdk
- update kernel headers to lastest versions (2.6.12-8mdk) and fix 
  malformed path in iptables-kernel-headers.tar.bz2
- fix lot of extensions test : Makefile check for $KERNEL_DIR/net/*/*/*.c
  but we provide only headers files ($KERNEL_DIR/include/linux/*/*.h)
  So test failed every time, and we don't get extension.
- add ipp2p extension, that is not in upstream iptables-1.3.2
- deleted extensions for linux-2.4 ( obsolete by now )

* Wed Jul 13 2005 Herton Ronaldo Krzesinski <herton@mandriva.com> 1.3.2-1mdk
- new upstream version: 1.3.2.
- redid stealth patch.
- obsoleted patch CAN-2004-0986.
- updated kernel headers to latest versions (2.6.12.2 & 2.4.31).

* Sat Apr 02 2005 Luca Berra <bluca@vodka.it> 1.2.9-8mdk 
- update kernel headers, we now have 4 flavors
- update initscript to test all flavors

* Tue Nov 02 2004 Vincent Danen <vdanen@mandrakesoft.com> 1.2.9-7.1.101mdk
- security fix for CAN-2004-0986

* Wed Jun 02 2004 Florin <florin@mandrakesoft.com> 1.2.9-7mdk
- add new extenions: see the kernel changelog here below
- netfilter (CLASSIFY CONNMARK IPMARK TARPIT addrtype condition 
	connbytes h323-conntrack-nat owner-socketlookup pptp-conntrack-nat 
	connlimit dstlimit iprange mport nth osf quota random time 
	rtsp-conntrack)

* Wed Jun 02 2004 Florin <florin@mandrakesoft.com> 1.2.9-6mdk
- add the devel package

* Sun Feb 15 2004 Luca Berra <bluca@vodka.it> 1.2.9-5mdk
- fix detection of iptables version at boot (again)

* Wed Jan 28 2004 Marcel Pol <mpol@mandrake.org> 1.2.9-4mdk
- update-alternatives seems unreliable, sorry

* Sun Jan 25 2004 Marcel Pol <mpol@mandrake.org> 1.2.9-3mdk
- doh, I can't read

* Sun Jan 25 2004 Luca Berra <bluca@vodka.it> 1.2.9-2mdk 
- compatible with both 2.4 and 2.6 (with and without pptp_conntrack)
- added check option to initscripts
- use alternatives (mpol)

* Fri Nov 28 2003 Juan Quintela <quintela@mandrakesoft.com> 1.2.9-1mdk
- IMQ should work now (cross fingers).
- reddiff stealth patch.
- 1.2.9.

* Wed Oct 08 2003 Juan Quintela <quintela@mandrakesoft.com> 1.2.9-0rc1mdk
- 1.2.9rc1.

* Tue Aug 26 2003 Juan Quintela <quintela@mandrakesoft.com> 1.2.8-2mdk
- added imq support.

